@@ -26,6 +26,8 @@ __all__ = [
     'ConfiguredDecision',
     'TrackedAction',
     'TrackedDecision',
+    'ThreadedTrackedAction',
+    'TrackedActionList',
 ]
 
 # todo figure out how to trigger a pre-trigger event (e.g. turn on instrument and condition)
