@@ -34,5 +34,5 @@ class Status(DumpableState):
         """represents the status as a dictionary"""
         return {
             'status_code': self.status_code,
-            'status': self.status,
+            'status': self.status_string,
         }
