@@ -1,9 +1,12 @@
+import warnings
+
 import time
 import logging
 import threading
 
 from typing import Union, MutableMapping, List, Callable, Type, Optional, Iterable
 from functools import wraps
+from abc import ABC
 
 from ..mixin.reg import InstanceRegistry
 
@@ -66,7 +69,10 @@ def ensure_component_inactive(fn: Callable):
     return decorated
 
 
-class TemporaryCallback:
+class TemporaryCallbackSetter(ABC):
+    # state set to temporarily assign callbacks to
+    _state_set_attribute: str = None
+
     def __init__(self,
                  *components: 'ComponentState',
                  callbacks: Union[Callable, Iterable[Callable]] = None,
@@ -89,16 +95,16 @@ class TemporaryCallback:
         # internal flag in the event that the callback is triggered
         self._callback_encountered = threading.Event()
 
-    def __enter__(self):
+    def __enter__(self) -> 'TemporaryCallbackSetter':
         for component in self.components:
-            for state in component.operational_states:
+            for state in getattr(component, self._state_set_attribute):
                 if state <= self.threshold_state:
                     state.register_callbacks(self.callback_capture, *self.callbacks)
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         for component in self.components:
-            for state in component.operational_states:
+            for state in getattr(component, self._state_set_attribute):
                 if state <= self.threshold_state:
                     state.deregister_callbacks(self.callback_capture, *self.callbacks)
 
@@ -112,6 +118,25 @@ class TemporaryCallback:
         self._callback_encountered.set()
 
 
+class TemporaryOperationalCallback(TemporaryCallbackSetter):
+    """context manager for temporarily applying callbacks to the operational states of the provided components"""
+    _state_set_attribute = 'operational_states'
+
+
+def TemporaryCallback(*args, **kwargs):
+    warnings.warn(  # v7.1.7
+        'TemporaryCallback was renamed TemporaryOperationalCallback',
+        DeprecationWarning,
+        stacklevel=2,
+    )
+    return TemporaryOperationalCallback(*args, **kwargs)
+
+
+class TemporaryActionCallback(TemporaryCallbackSetter):
+    """context manager for temporarily applying callbacks to the action states of the provided components"""
+    _state_set_attribute = 'action_states'
+
+
 class ComponentState(InstanceRegistry):
 
     # dedicated component-specific mapping
