@@ -2,16 +2,17 @@ import threading
 import time
 import unittest
 from hein_control.states import (ComponentState, OperationalState, ensure_component_online, ensure_component_inactive,
-                                 BadComponentState, GenericActionState, TemporaryCallback)
+                                 BadComponentState, GenericActionState, TemporaryOperationalCallback,
+                                 TemporaryActionCallback)
 from hein_control.states.abc import State, StateSet
 
 
 class CustomActiveState(StateSet):
-    IDLE = 0
-    ACTIVE = 1
-    HYPERACTIVE = 2
+    IDLE = State(0)
+    ACTIVE = State(1)
+    HYPERACTIVE = State(2)
     JUMP_JUMP = 3
-    BOOGIE_WOOGIE = 4
+    BOOGIE_WOOGIE = State(4)
     # can you tell I have a two year old?
 
 
@@ -342,6 +343,7 @@ class SoManyStates(StateSet):
 
 class AllTheStates(ComponentState):
     operational_states = SoManyStates
+    action_states = CustomActiveState
 
 
 class TestTemporaryCallback(unittest.TestCase):
@@ -374,8 +376,8 @@ class TestTemporaryCallback(unittest.TestCase):
         """tests setting of the default callback method"""
         with self.lock:
             try:
-                with TemporaryCallback(self.component) as tcb:
-                    self.assertIsInstance(tcb, TemporaryCallback, 'ensure callback TemporaryCallback instance is returned')
+                with TemporaryOperationalCallback(self.component) as tcb:
+                    self.assertIsInstance(tcb, TemporaryOperationalCallback, 'ensure callback TemporaryOperationalCallback instance is returned')
                     self.check_assigned(tcb.callback_capture)
                     self.component.update_operational_state(-1)
                     self.assertTrue(tcb.callback_encountered, 'ensure callback was encountered')
@@ -392,14 +394,14 @@ class TestTemporaryCallback(unittest.TestCase):
         """tests that the callback was only applied to states at or below the threshold"""
         with self.lock:
             for threshold_state in self.component.operational_states:
-                with TemporaryCallback(self.component, threshold_state=threshold_state) as tcb:
+                with TemporaryOperationalCallback(self.component, threshold_state=threshold_state) as tcb:
                     self.check_assigned(tcb.callback_capture, threshold_state)
 
     def test_custom_callback(self):
         """tests custom callback setting"""
         with self.lock:
             try:
-                with TemporaryCallback(self.component, callbacks=self.custom_callback) as tcb:
+                with TemporaryOperationalCallback(self.component, callbacks=self.custom_callback) as tcb:
                     self.check_assigned(self.custom_callback)
                     self.assertRaises(ValueError, self.change_state_wait)
                 self.assertTrue(tcb.callback_encountered)
@@ -417,3 +419,22 @@ class TestTemporaryCallback(unittest.TestCase):
         """
         time.sleep(0.1)
         self.component.update_operational_state(-1)
+
+    def test_action_callback(self):
+        """tests action callback setting"""
+        threshold_state = self.component.action_states(2)
+        with TemporaryActionCallback(self.component, callbacks=[self.custom_callback], threshold_state=threshold_state) as tcb:
+            self.assertIsInstance(tcb, TemporaryActionCallback, 'ensure TemporaryActionCallback is returned')
+            for state in self.component.action_states:
+                if state <= threshold_state:
+                    self.assertTrue(state.has_callbacks, f'ensure callback was assigned to {state}')
+                    self.assertTrue(
+                        self.custom_callback in state.value.callbacks,
+                        f'ensure correct callback was assigned to {state}'
+                    )
+                elif hasattr(state.value, 'callbacks'):
+                    self.assertFalse(state.has_callbacks, 'ensure callback was not assigned to states above threshold')
+                    self.assertFalse(
+                        self.custom_callback in state.value.callbacks,
+                        f'ensure callback was not assigned to {state}'
+                    )
